@@ -21,7 +21,7 @@ from Orange.OrangeWidgets.OWWidget import *
 
 import orangecontrib.bio.widgets.OWPIPAx as OWPIPAx
 
-
+import requests
 from orangecontrib.bio import obiDicty
 
 NAME = "GenCloud"
@@ -44,6 +44,9 @@ def to_text(x):
     else:
         return x
 
+class GenCountConnectionException(Exception):
+    pass
+
 class Genesis(object):
 
     #ignore when joining replicates
@@ -68,7 +71,7 @@ class Genesis(object):
           ("shearing", "Shearing")]
 
     def __init__(self, address, cache=None,
-                 username=None, password=None):
+                 username="", password="", connect=True):
 
         """
         :param str address: The address of the API. 
@@ -80,16 +83,26 @@ class Genesis(object):
         self.address = address
         self.buffer = cache
         self.username = username
-
-        self.gen = genapi.GenCloud(username, password, address)
+        self.password = password
+        self._gen = None
+        if connect:
+            self._gen = genapi.GenCloud(username, password, address)
         self._project = None
         self.projectid = None
 
+    @property
+    def gen(self):
+        if not self._gen:
+            try:
+                self._gen = genapi.GenCloud(self.username, self.password, self.address)
+            except:
+                raise GenCountConnectionException("Connection needed")
+        return self._gen
+
     @property
     def project(self):
         if not self._project or self._project.id != self.projectid:
             self._project = self.gen.projects()[self.projectid]
-            #print "LOADED PROJECT", str(self._project)
         return self._project
 
     def projects(self, reload=False, bufver="0"):
@@ -124,19 +137,23 @@ class Genesis(object):
             rdict = {}
             for o in objects:
                 an = o.annotation
+                ok = False
                 for path, a in an.iteritems():
                     if path.startswith('output') and a['type'] == 'basic:file:' \
                         and a["name"] == rtype:
-                        rdict[o.id] = an
+                            ok = True  
+                if ok:
+                    rdict[o.id] = an
+                    rdict[o.id]["date_modified"] = o.date_modified
             return rdict
         return self._buffer_fn(self.projectid + "|||" + self.username + "|||" + "results_list"  + "|||" + str(rtype), bufver, reload, a, self)
 
     def _from_buffer(self, addr):
-        return self.buffer.get(self.address + "|||" + addr)
+        return self.buffer.get(self.address + "|v1||" + addr)
 
     def _to_buffer(self, addr, cont, version="0", autocommit=True):
         if self.buffer:
-            return self.buffer.add(self.address + "|||" + addr, cont, version=version, autocommit=autocommit)
+            return self.buffer.add(self.address + "|v1||" + addr, cont, version=version, autocommit=autocommit)
 
     def _buffer_commit(self):
         if self.buffer:
@@ -159,17 +176,12 @@ class Genesis(object):
 
     def _in_buffer(self, addr):
         if self.buffer:
-            return self.buffer.contains(self.address + "|||" + addr)
+            return self.buffer.contains(self.address + "|v1||" + addr)
         else:
             return False
 
-    def objects(self, reload=False, bufver="0"):
-        def a(self):
-            return { id: o.annotation for id, o in self.project.objects().items() }
-        return self._buffer_fn(self.projectid + "|||" + self.username + "|||" + "objects", bufver, reload, a, self)
-
     def download(self, ids, rtype, reload=False, bufver="0"):
-        objdic = self.objects(reload, bufver)
+        objdic = self.results_list(rtype)
 
         downloads = [] #what to download
         for id in ids:
@@ -182,13 +194,17 @@ class Genesis(object):
                             field = a["value"]["file"]
             downloads.append((id, field))
 
+        bufverfn = (lambda x: bufver) if isinstance(bufver, basestring) else bufver
+
         unbuffered = [] #what is missing
         for id,field in downloads:
-            if not self._in_buffer(id + "|||" + rtype) or reload:
+            if not self._in_buffer(id + "|||" + rtype) == bufverfn(id) or reload:
                 unbuffered.append((id, field))
         unbufferedset = set(unbuffered)
 
-        newgen = self.gen.download(unbuffered)
+        newgen = [].__iter__()
+        if unbuffered:
+            newgen = self.gen.download(unbuffered)
         for id,field in downloads:
             if (id, field) in unbufferedset:
                 response = newgen.next()
@@ -197,7 +213,7 @@ class Genesis(object):
                     if l:
                         gene, val = l.split('\t')
                         out.append((str(gene), str(val)))
-                self._to_buffer(id + "|||" + rtype, out, autocommit=True)
+                self._to_buffer(id + "|||" + rtype, out, version=bufverfn(id), autocommit=True)
                 yield out
             else:
                 yield self._from_buffer(id + "|||" + rtype)
@@ -238,7 +254,7 @@ class Genesis(object):
 
         cbc = CallBack(len(ids), optcb, callbacks=10)
 
-        res_list = self.results_list(result_type, reload=reload, bufver=bufver)
+        res_list = self.results_list(result_type, reload=reload)
 
         #annotations
         read = {}
@@ -279,13 +295,6 @@ class Genesis(object):
         return et
 
 
-try:
-    from ast import literal_eval
-except ImportError:
-    #avoid eval on older pythons: dates are of lower importance than safety
-    literal_eval = lambda x: None
-
-
 def tfloat(s):
     try:
         return float(s)
@@ -342,7 +351,7 @@ class OWGenCloud(OWWidget):
     settingsList = ["server", "excludeconstant", "username", "password",
                     "joinreplicates", "selectionSetsWidget.selections",
                     "columnsSortingWidget.sortingOrder", "currentSelection",
-                    "log2", "experimentsHeaderState", "rtypei" ]
+                    "log2", "experimentsHeaderState", "rtypei", "projecti" ]
 
     def __init__(self, parent=None, signalManager=None, name="Genesis"):
         OWWidget.__init__(self, parent, signalManager, name)
@@ -351,8 +360,7 @@ class OWGenCloud(OWWidget):
         self.username = ""
         self.password = ""
         self.log2 = False
-        self.rtypei = 5 #hardcoded rpkm mapability polya
-
+        self.rtypei = 0
         self.projecti = 0
 
         self.selectedExperiments = []
@@ -362,6 +370,8 @@ class OWGenCloud(OWWidget):
         self.excludeconstant = False
         self.joinreplicates = False
         self.currentSelection = None
+    
+        self.items = []
 
         self.experimentsHeaderState = \
                 dict(((name, False) for _, name in HEADER[:ID_INDEX + 1]))
@@ -504,7 +514,11 @@ class OWGenCloud(OWWidget):
 
     def ConnectAndUpdate(self):
         self.Connect()
-        self.UpdateExperiments(reload=False)
+        if self.dbc:
+            self.projects = sorted(self.dbc.projects().items(), key=lambda x: x[1])
+            self.UpdateProjects()
+            self.ProjectChosen()
+            self.UpdateExperimentTypes()
 
     def Connect(self):
         self.error(1)
@@ -525,19 +539,18 @@ class OWGenCloud(OWWidget):
                                   username=username,
                                   password=password,
                                   cache=self.buffer)
-        except Exception:
-            self.error(1, "Wrong username or password")
-            self.dbc = None
+        except requests.exceptions.ConnectionError:
+            self.dbc = Genesis(address="http://cloud.genialis.com/", 
+                                  username=username,
+                                  password=password,
+                                  connect=False,
+                                  cache=self.buffer)
+            self.warning(1, "Could not connect to server, working from cache.")
+        except Exception, ex:
+            self.error(1, "Wrong username or password.")
 
         self.UpdateProjects()
-        self.UpdateExperimentTypes()
-
-        if self.dbc:
-            self.projects = sorted(self.dbc.projects().items(), key=lambda x: x[1])
-            self.UpdateProjects()
-            self.ProjectChosen()
-            self.UpdateExperimentTypes()
-
+        self.UpdateExperimentTypes() #clear lists
 
     def Reload(self):
         self.UpdateExperiments(reload=True)
@@ -557,14 +570,17 @@ class OWGenCloud(OWWidget):
         self.expressionTypesCB.clear()
         items = [desc for desc  in self.result_types]
         self.expressionTypesCB.addItems(items)
-        self.rtypei = max(0, min(self.rtypei, len(self.result_types) - 1))
+        #do not update anything if the list is empty
+        if len(self.result_types):
+            self.rtypei = max(0, min(self.rtypei, len(self.result_types) - 1))
 
     def UpdateProjects(self):
         self.projectCB.clear()
         items = [desc for pid,desc in self.projects]
         self.projectCB.addItems(items)
-        self.projecti = max(0, min(self.projecti, len(self.projects) - 1))
-
+        #do not update anathing if the list if empty
+        if len(self.projects) > 0:
+            self.projecti = max(0, min(self.projecti, len(self.projects) - 1))
 
     def UpdateExperiments(self, reload=False):
 
@@ -601,7 +617,7 @@ class OWGenCloud(OWWidget):
         self.UpdateResultsList(reload=reload)
 
         self.progressBarFinished()
-
+        
         if self.currentSelection:
             self.currentSelection.select(self.experimentsWidget.selectionModel())
 
@@ -660,8 +676,7 @@ class OWGenCloud(OWWidget):
         for i in range(len(self.headerLabels)):
             self.experimentsWidget.resizeColumnToContents(i)
 
-        # FIXME: what attribute to use for version?
-        self.wantbufver = lambda x: "0"
+        self.wantbufver = lambda x: self.results_list[x]["date_modified"]
 
         self.UpdateCached()
 
@@ -673,7 +688,6 @@ class OWGenCloud(OWWidget):
             for item in self.items:
                 id = str(item.text(ID_INDEX))
                 version = self.dbc._in_buffer(id + "|||" + self.rtype())
-                #print self.results_list
                 value = " " if version == self.wantbufver(id) else ""
                 item.setData(0, Qt.DisplayRole, QVariant(value))
 
@@ -718,7 +732,7 @@ class OWGenCloud(OWWidget):
             table = self.dbc.get_data(ids=ids, result_type=self.rtype(),
                           callback=pb.advance,
                           exclude_constant_labels=self.excludeconstant,
-#                          bufver=self.wantbufver,
+                          bufver=self.wantbufver,
                           transform=transfn,
                           allowed_labels=allowed_labels)
 
